searchData={"items":[{"type":"extras","title":"Raspberry Pi 2 Model B","doc":"# Raspberry Pi 2 Model B\n\n[![CircleCI](https://circleci.com/gh/nerves-project/nerves_system_rpi2.svg?style=svg)](https://circleci.com/gh/nerves-project/nerves_system_rpi2)\n\nThis is the base Nerves System configuration for the Raspberry Pi 2 Model B.\n\n![Fritzing Raspberry Pi 2 image](assets/images/raspberry-pi-2-model-b.png)\n  [Image credit](#fritzing) \n\n| Feature              | Description                     |\n| -------------------- | ------------------------------- |\n| CPU                  | 900 MHz quad-core ARM Cortex-A7 |\n| Memory               | 1 GB DRAM                       |\n| Storage              | MicroSD                         |\n| Linux kernel         | 6.1 w/ Raspberry Pi patches     |\n| IEx terminal         | HDMI and USB keyboard (can be changed to UART)   |\n| GPIO, I2C, SPI       | Yes - [Elixir Circuits](https://github.com/elixir-circuits) |\n| ADC                  | No                              |\n| PWM                  | Yes, but no Elixir support      |\n| UART                 | 1 available - `ttyAMA0`         |\n| Camera               | Yes - via rpi-userland          |\n| Ethernet             | Yes                             |\n| WiFi                 | Requires USB WiFi dongle        |\n| Bluetooth            | Not supported                   |\n| Audio                | HDMI/Stereo out                 |","ref":"readme.html"},{"type":"extras","title":"Using - Raspberry Pi 2 Model B","doc":"The most common way of using this Nerves System is create a project with `mix\nnerves.new` and to export `MIX_TARGET=rpi2`. See the [Getting started\nguide](https://hexdocs.pm/nerves/getting-started.html#creating-a-new-nerves-app)\nfor more information.\n\nIf you need custom modifications to this system for your device, clone this\nrepository and update as described in [Making custom\nsystems](https://hexdocs.pm/nerves/customizing-systems.html).","ref":"readme.html#using"},{"type":"extras","title":"Supported USB WiFi devices - Raspberry Pi 2 Model B","doc":"The base image includes drivers and firmware for Ralink RT53xx\n(`rt2800usb` driver), RealTek RTL8712U (`r8712u` driver) and\nRealTek RTL 8192 (`rtl8192cu` driver) devices (e.g. Edimax USB WiFi dongles).\n\nWe are still working out which subset of all possible WiFi dongles to\nsupport in our images. At some point, we may have the option to support\nall dongles and selectively install modules at packaging time, but until\nthen, these drivers and their associated firmware blobs add significantly\nto Nerves release images.\n\nIf you are unsure what driver your WiFi dongle requires, run Raspbian and\nconfigure WiFi for your device. At a shell prompt, run `lsmod` to see which\ndrivers are loaded.  Running `dmesg` may also give a clue. When using `dmesg`,\nreinsert the USB dongle to generate new log messages if you don't see them.","ref":"readme.html#supported-usb-wifi-devices"},{"type":"extras","title":"Audio - Raspberry Pi 2 Model B","doc":"The Raspberry Pi has many options for audio output. This system supports the\nHDMI and stereo audio jack output. The Linux ALSA drivers are used for audio\noutput.\n\nThe general Raspberry Pi audio documentation mostly applies to Nerves. For\nexample, to force audio out the HDMI port, run:\n\n```elixir\ncmd(\"amixer cset numid=3 2\")\n```\n\nChange the last argument to `amixer` to `1` to output to the stereo output jack.","ref":"readme.html#audio"},{"type":"extras","title":"Provisioning devices - Raspberry Pi 2 Model B","doc":"This system supports storing provisioning information in a small key-value store\noutside of any filesystem. Provisioning is an optional step and reasonable\ndefaults are provided if this is missing.\n\nProvisioning information can be queried using the Nerves.Runtime KV store's\n[`Nerves.Runtime.KV.get/1`](https://hexdocs.pm/nerves_runtime/Nerves.Runtime.KV.html#get/1)\nfunction.\n\nKeys used by this system are:\n\nKey                    | Example Value     | Description\n:--------------------- | :---------------- | :----------\n`nerves_serial_number` | `\"12345678\"`      | By default, this string is used to create unique hostnames and Erlang node names. If unset, it defaults to part of the Raspberry Pi's device ID.\n\nThe normal procedure would be to set these keys once in manufacturing or before\ndeployment and then leave them alone.\n\nFor example, to provision a serial number on a running device, run the following\nand reboot:\n\n```elixir\niex> cmd(\"fw_setenv nerves_serial_number 12345678\")\n```\n\nThis system supports setting the serial number offline. To do this, set the\n`NERVES_SERIAL_NUMBER` environment variable when burning the firmware. If you're\nprogramming MicroSD cards using `fwup`, the commandline is:\n\n```sh\nsudo NERVES_SERIAL_NUMBER=12345678 fwup path_to_firmware.fw\n```\n\nSerial numbers are stored on the MicroSD card so if the MicroSD card is\nreplaced, the serial number will need to be reprogrammed. The numbers are stored\nin a U-boot environment block. This is a special region that is separate from\nthe application partition so reformatting the application partition will not\nlose the serial number or any other data stored in this block.\n\nAdditional key value pairs can be provisioned by overriding the default\nprovisioning.conf file location by setting the environment variable\n`NERVES_PROVISIONING=/path/to/provisioning.conf`. The default provisioning.conf\nwill set the `nerves_serial_number`, if you override the location to this file,\nyou will be responsible for setting this yourself.","ref":"readme.html#provisioning-devices"},{"type":"extras","title":"Linux kernel and RPi firmware/userland - Raspberry Pi 2 Model B","doc":"There's a subtle coupling between the `nerves_system_br` version and the Linux\nkernel version used here. `nerves_system_br` provides the versions of\n`rpi-userland` and `rpi-firmware` that get installed. I prefer to match them to\nthe Linux kernel to avoid any issues. Unfortunately, none of these are tagged by\nthe Raspberry Pi Foundation so I either attempt to match what's in Raspbian or\ntake versions of the repositories that have similar commit times.\n\n[Image credit](#fritzing): This image is from the [Fritzing](http://fritzing.org/home/) parts library.","ref":"readme.html#linux-kernel-and-rpi-firmware-userland"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nThis project does NOT follow semantic versioning. The version increases as\nfollows:\n\n1. Major version updates are breaking updates to the build infrastructure.\n   These should be very rare.\n2. Minor version updates are made for every major Buildroot release. This\n   may also include Erlang/OTP and Linux kernel updates. These are made four\n   times a year shortly after the Buildroot releases.\n3. Patch version updates are made for Buildroot minor releases, Erlang/OTP\n   releases, and Linux kernel updates. They're also made to fix bugs and add\n   features to the build infrastructure.","ref":"changelog.html"},{"type":"extras","title":"v1.27.0 - Changelog","doc":"This is a major Buildroot update.\n\nPlease see the [nerves_system_br v1.27.0 release notes](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.26.0)\nfor upgrade instructions if you've forked this system.\n\n* Changes\n  * The `libcamera` and `rpicam_apps` packages have been replaced with the\n    Raspberry Pi-forked versions for better compatibility. Please see\n    `nerves_system_br` release notes.\n\n* Updated dependencies\n  * Linux 6.1.73 (Raspberry Pi 20240124 release)\n  * [nerves_system_br v1.27.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.27.0)\n  * [Buildroot 2024.02](https://lore.kernel.org/buildroot/87msrczp4z.fsf@48ers.dk/)\n  * [Erlang/OTP 26.2.3](https://erlang.org/download/OTP-26.2.3.README)","ref":"changelog.html#v1-27-0"},{"type":"extras","title":"v1.26.0 - Changelog","doc":"This is a major Buildroot update.\n\nPlease see the [nerves_system_br v1.26.0 release notes](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.26.0)\nfor upgrade instructions if you've forked this system.\n\n* Updated dependencies\n  * [Erlang/OTP 26.2.2](https://erlang.org/download/OTP-26.2.2.README)\n  * [nerves_system_br v1.26.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.26.1)\n  * [Buildroot 2023.11.1](https://lore.kernel.org/buildroot/87cyu2k2gu.fsf@48ers.dk/T/)","ref":"changelog.html#v1-26-0"},{"type":"extras","title":"v1.25.1 - Changelog","doc":"This is a security/bug fix update.\n\n* Changes\n  * Synchronize configuration closer to the rpi3 options\n\n*  Package updates\n  * [Erlang/OTP 26.2.1](https://erlang.org/download/OTP-26.2.1.README)\n  * [nerves_heart 2.3.0](https://github.com/nerves-project/nerves_heart/releases/tag/v2.3.0)","ref":"changelog.html#v1-25-1"},{"type":"extras","title":"v1.25.0 - Changelog","doc":"This is a major Buildroot, toolchain, and Linux kernel update that also adds\nsupport for using Scenic without customizing the system.\n\nPlease see [nerves_system_br v1.25.0 release notes](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.25.0)\nfor upgrade instructions if you've forked this system.\n\n* New features\n  * Add libcairo for [Scenic](https://github.com/ScenicFramework/scenic) support\n\n* Updated dependencies\n  * Linux 6.1.63 (Raspberry Pi stable_20231123 release)\n  * [nerves_system_br v1.25.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.25.2)\n  * [Buildroot 2023.08.4](https://lore.kernel.org/buildroot/87o7f6t7fs.fsf@48ers.dk/T/)\n  * [Erlang/OTP 26.1.2](https://erlang.org/download/OTP-26.1.2.README)","ref":"changelog.html#v1-25-0"},{"type":"extras","title":"v1.24.1 - Changelog","doc":"This is a security/bug fix update.\n\n* Package updates\n  * [nerves_system_br v1.24.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.24.1)\n  * [Erlang/OTP 26.1.1](https://erlang.org/download/OTP-26.1.1.README)\n  * [Buildroot 2023.05.3](https://lore.kernel.org/buildroot/87h6ngup34.fsf@48ers.dk/T/)","ref":"changelog.html#v1-24-1"},{"type":"extras","title":"v1.24.0 - Changelog","doc":"This is a Buildroot version update that appears to mostly contain bug and\nsecurity fixes. It should be a low risk upgrade from v1.23.2.\n\n* New features\n  * Support factory reset, preventing firmware reverts. See [Nerves.Runtime.FwupOps](https://hexdocs.pm/nerves_runtime/Nerves.Runtime.FwupOps.html)\n\n* Updated dependencies\n  * [nerves_system_br v1.24.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.24.0)\n  * [Buildroot 2023.05.2](https://lore.kernel.org/buildroot/87ledrkrpp.fsf@48ers.dk/T/), [2023.05.1](https://lore.kernel.org/buildroot/87351m8qm4.fsf@48ers.dk/T/), [2023.05](https://lore.kernel.org/buildroot/87r0qn2c77.fsf@48ers.dk/T/)\n  * [Erlang/OTP 26.1](https://erlang.org/download/OTP-26.1.README)","ref":"changelog.html#v1-24-0"},{"type":"extras","title":"v1.23.2 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.23.3](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.23.3)","ref":"changelog.html#v1-23-2"},{"type":"extras","title":"v1.23.1 - Changelog","doc":"This is a bug and security fix update. It should be a low risk upgrade.\n\n* Fixes\n  * Fix CTRL+R over ssh\n\n* Updated dependencies\n  * [nerves_system_br v1.23.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.23.2)\n  * [Buildroot 2023.02.2](https://lore.kernel.org/buildroot/87y1je6wva.fsf@48ers.dk/T/)","ref":"changelog.html#v1-23-1"},{"type":"extras","title":"v1.23.0 - Changelog","doc":"This is a major update that brings in Erlang/OTP 26, Buildroot 2023.02.2, Linux\n5.15.84, and Raspberry Pi firmware updates.\n\n* New features\n  * CA certificates are included for OTP 26.\n\n* Updated dependencies\n  * [nerves_system_br v1.23.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.23.1)\n  * [Buildroot 2023.02.2](https://lore.kernel.org/buildroot/87wn03ifbl.fsf@48ers.dk/T/)\n  * [Erlang/OTP 26.0.2](https://erlang.org/download/OTP-26.0.2.README)\n  * Linux 5.15.84 (Raspberry Pi Linux tag 1.20230106)","ref":"changelog.html#v1-23-0"},{"type":"extras","title":"v1.22.2 - Changelog","doc":"This is a bug and security fix update. It should be a low risk upgrade from\nv1.22.1.\n\n* Updated dependencies\n  * [nerves_system_br v1.22.5](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.22.5)\n  * [Buildroot 2022.11.3](https://lore.kernel.org/buildroot/878rfuxbxx.fsf@dell.be.48ers.dk/T/)","ref":"changelog.html#v1-22-2"},{"type":"extras","title":"v1.22.1 - Changelog","doc":"This is a bug fix and Erlang version bump from 25.2 to 25.2.3. It should be a\nlow risk upgrade from v1.22.0.\n\n* Updated dependencies\n  * [nerves_system_br v1.22.3](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.22.3)\n  * [Buildroot 2022.11.1](https://lore.kernel.org/buildroot/87ilh4dvax.fsf@dell.be.48ers.dk/T/#u)","ref":"changelog.html#v1-22-1"},{"type":"extras","title":"v1.22.0 - Changelog","doc":"This is a Buildroot version update that appears to mostly contain bug and\nsecurity fixes. It should be a low risk upgrade to v1.21.2.\n\n* Updated dependencies\n  * [nerves_system_br v1.22.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.22.1)\n  * [Buildroot 2022.11](http://lists.busybox.net/pipermail/buildroot/2022-December/656980.html)\n  * GCC 12.2","ref":"changelog.html#v1-22-0"},{"type":"extras","title":"v1.21.2 - Changelog","doc":"* Changes\n  * Two Buildroot patch updates and an Erlang minor version update\n  * Nerves Heart v2.0 is now included. Nerves Heart connects the Erlang runtime\n    to a hardware watchdog. v2.0 has numerous updates to improve information\n    that you can get and also has more safeguards to avoid conditions that could\n    cause a device to hang forever.\n\n* Updated dependencies\n  * linux 5.15.78 (RPi 1.20221104)\n  * [nerves_system_br v1.21.6](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.21.6)\n  * [Erlang/OTP 25.2](https://erlang.org/download/OTP-25.2.README)\n  * [Buildroot 2022.08.3](https://lore.kernel.org/buildroot/87r0x7z5cw.fsf@dell.be.48ers.dk/T/#u)\n  * [nerves_heart v2.0.2](https://github.com/nerves-project/nerves_heart/releases/tag/v2.0.2)","ref":"changelog.html#v1-21-2"},{"type":"extras","title":"v1.21.1 - Changelog","doc":"* Changes\n  * Reduce first-time Linux kernel download by using tarball source\n\n* Updated dependencies\n  * [nerves_system_br v1.21.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.21.2)\n  * [Erlang/OTP 25.1.2](https://erlang.org/download/OTP-25.1.2.README)","ref":"changelog.html#v1-21-1"},{"type":"extras","title":"v1.21.0 - Changelog","doc":"* Changes\n  * Support aarch64 Linux builds\n  * Add libdtc to support runtime loading of device tree overlays\n\n* Updated dependencies\n  * [nerves_system_br v1.21.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.21.1)\n    and also see [nerves_system_br v1.21.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.21.0)\n  * [Buildroot 2022.08.1](http://lists.busybox.net/pipermail/buildroot/2022-October/652816.html)\n  * [Erlang/OTP 25.1.1](https://erlang.org/download/OTP-25.1.1.README)","ref":"changelog.html#v1-21-0"},{"type":"extras","title":"v1.20.2 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.20.6](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.20.6)\n  * [Erlang/OTP 25.0.4](https://erlang.org/download/OTP-25.0.4.README)\n  * [Buildroot 2022.05.2](http://lists.busybox.net/pipermail/buildroot/2022-August/650546.html)\n  * Also see [Buildroot 2022.05.1 changes](http://lists.busybox.net/pipermail/buildroot/2022-July/647814.html)","ref":"changelog.html#v1-20-2"},{"type":"extras","title":"v1.20.1 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.20.4](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.20.4)\n  * [Erlang/OTP 25.0.3](https://erlang.org/download/OTP-25.0.3.README)","ref":"changelog.html#v1-20-1"},{"type":"extras","title":"v1.20.0 - Changelog","doc":"This release updates to Buildroot 2022.05, Linux 5.15.32 (from Linux 5.10) and\nuses GCC 11.3 (from GCC 10.3). The Linux kernel upgrade could introduce a\nregression, so please verify hardware-specific functionality in your firmware.\n\nIf you have cloned this repository for a custom system, please make sure that\nyou have `CONFIG_NOP_USB_XCEIV=y` in your Linux kernel configuration.\n\n* Updated dependencies\n  * [nerves_system_br v1.20.3](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.20.3)\n  * [Buildroot 2022.05](http://lists.busybox.net/pipermail/buildroot/2022-June/644349.html)\n  * [Erlang/OTP 25.0.2](https://erlang.org/download/OTP-25.0.2.README)","ref":"changelog.html#v1-20-0"},{"type":"extras","title":"v1.19.0 - Changelog","doc":"This release updates to Buildroot 2022.02.1 and OTP 25.0. While this should be\nan easy update for most projects, many programs have been updated. Please review\nthe changes in the updated dependencies for details.\n\n* Updated dependencies\n  * [nerves_system_br v1.19.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.19.0)\n  * [Buildroot 2022.02.1](http://lists.busybox.net/pipermail/buildroot/2022-April/640712.html). Also see [Buildroot 2022.02](http://lists.busybox.net/pipermail/buildroot/2022-March/638160.html)\n  * [Erlang/OTP 25.0](https://erlang.org/download/OTP-25.0.README)","ref":"changelog.html#v1-19-0"},{"type":"extras","title":"v1.18.4 - Changelog","doc":"This release bumps Erlang to 24.3.2 and should be a low risk upgrade from the\nprevious release.\n\n* Changes\n  * Pull in upstream Linux SquashFS patch to improve file system performance\n\n* Updated dependencies\n  * [nerves_system_br v1.18.6](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.18.6)","ref":"changelog.html#v1-18-4"},{"type":"extras","title":"v1.18.3 - Changelog","doc":"This is a Buildroot and Erlang bug and security fix release. It should be a low\nrisk upgrade from the previous release.\n\n* Updated dependencies\n  * [nerves_system_br v1.18.5](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.18.5)","ref":"changelog.html#v1-18-3"},{"type":"extras","title":"v1.18.2 - Changelog","doc":"This is a Buildroot and Erlang bug fix release. It should be a low risk upgrade\nfrom the previous release.\n\n* Updated dependencies\n  * [nerves_system_br v1.18.4](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.18.4)\n\n* Changes\n  * Specify CPU-specific flags when compiling NIFs and ports. This fixes an\n    issue where some optimizations could not be enabled in NIFs even though it\n    should be possible to have them. E.g., ARM NEON support for CPUs that have\n    it.\n  * Build the Wireguard kernel driver. This is a small device driver that\n    enables a number of VPN-based use cases.","ref":"changelog.html#v1-18-2"},{"type":"extras","title":"v1.18.1 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.18.3](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.18.3)\n\n* Changes\n  * The `cpufreq` directories are available again. This was a regression that\n    would break code that manually adjusted the CPU frequency.\n  * Programs that use OpenMP will run now. The OpenMP shared library\n    (`libgomp.so`) was supplied by the toolchain, but not copied.","ref":"changelog.html#v1-18-1"},{"type":"extras","title":"v1.18.0 - Changelog","doc":"This release updates to Buildroot 2021.11 and OTP 24.2. If you have made a\ncustom system, please review the `nerves_system_br` [release\nnotes](https://github.com/nerves-project/nerves_system_br/blob/v1.18.2/CHANGELOG.md#v1180)\nsince Buildroot 2021.11 changed some Raspberry Pi firmware options.\n\n* Updated dependencies\n  * [nerves_system_br v1.18.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.18.2)\n  * [Buildroot 2021.11](http://lists.busybox.net/pipermail/buildroot/2021-December/629911.html)\n  * [Erlang/OTP 24.2](https://erlang.org/download/OTP-24.2.README)\n  * [Raspberry Pi WiFi firmware](https://github.com/RPi-Distro/firmware-nonfree/blob/bullseye/debian/changelog)\n  * Linux 5.10.88 with Raspberry Pi patches\n  * GCC 10.3\n\n* Improvements\n  * Support for the `dl.nerves-project.org` backup site. Due to a GitHub outage\n    in November, there was a 2 day period of failing builds since some packages\n    could not be downloaded. We implemented the backup site to prevent this in\n    the future. This update is in the `nerves_defconfig`.\n  * Use new build ORB on CircleCI. This ORB will shorten build times to fit in\n    CircleCI's new free tier limits. Please update if building your own systems.","ref":"changelog.html#v1-18-0"},{"type":"extras","title":"v1.17.3 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.17.4](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.17.4)\n  * [Buildroot 2021.08.2](http://lists.busybox.net/pipermail/buildroot/2021-November/628323.html)\n  * [Erlang/OTP 24.1.7](https://erlang.org/download/OTP-24.1.7.README).","ref":"changelog.html#v1-17-3"},{"type":"extras","title":"v1.17.2 - Changelog","doc":"This release updates the Linux kernel from 5.4 to 5.10 to follow the Raspberry\nPi OS.\n\n* Updated dependencies\n  * [nerves_system_br v1.17.3](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.17.3)\n  * [Erlang/OTP 24.1.4](https://erlang.org/download/OTP-24.1.4.README).\n  * Linux 5.10.63 with Raspberry Pi patches","ref":"changelog.html#v1-17-2"},{"type":"extras","title":"v1.17.1 - Changelog","doc":"This is a security/bug fix patch release. It should be safe to update for\neveryone.\n\n* Updated dependencies\n  * [nerves_system_br v1.17.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.17.1)\n  * [Buildroot 2021.08.1](http://lists.busybox.net/pipermail/buildroot/2021-October/625642.html)\n  * [Erlang/OTP 24.1.2](https://erlang.org/download/OTP-24.1.2.README)\n\n* Improvements\n  * Include software versioning and licensing info (see legal-info directory in\n    artifact)","ref":"changelog.html#v1-17-1"},{"type":"extras","title":"v1.17.0 - Changelog","doc":"This release updates to Buildroot 2021.08 and OTP 24.1. If you have made a\ncustom system off this one, please review the `nerves_system_br v1.17.0` release\nnotes.\n* Updated dependencies\n  * [nerves_system_br v1.17.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.17.0)\n  * [Buildroot 2021.08](http://lists.busybox.net/pipermail/buildroot/2021-September/622072.html)\n  * [Erlang/OTP 24.1](https://erlang.org/download/OTP-24.1.README)","ref":"changelog.html#v1-17-0"},{"type":"extras","title":"v1.16.2 - Changelog","doc":"This release updates Erlang/OTP from 24.0.3 to 24.0.5 and Buildroot from 2021.05\nto 2021.05.1. Both of these are security/bug fix updates. This is expected to be\na safe upgrade from v1.16.1 for all users.\n\n* Updated dependencies\n  * [nerves_system_br v1.16.4](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.16.1)\n  * [Erlang/OTP 24.0.5](https://erlang.org/download/OTP-24.0.5.README)\n\n* Improvements\n  * Beta support for using a `runtime.exs` script for runtime configuration.\n  * Added a `provision` task to the `fwup.config` to enable re-provisioning a\n    MicroSD card without changing its contents.\n  * Adds a default `/etc/sysctl.conf` that enables use of ICMP in Erlang. This\n    requires `nerves_runtime v0.11.5` or later to automatically load the sysctl\n    variables. With it using `:gen_udp` to send/receive ICMP will \"just work\".\n    It also makes it easier to add other sysctl variables if needed.","ref":"changelog.html#v1-16-2"},{"type":"extras","title":"v1.16.1 - Changelog","doc":"This release updates Nerves Toolchains to v1.4.3 and OTP 24.0.3. It should be safe for everyone to apply.\n\n* Updated dependencies\n  * [nerves_system_br v1.16.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.16.1)\n  * [Erlang/OTP 24.0.3](https://erlang.org/download/OTP-24.0.3.README)\n  * [nerves toolchains v1.4.3](https://github.com/nerves-project/toolchains/releases/tag/v1.4.3)","ref":"changelog.html#v1-16-1"},{"type":"extras","title":"v1.16.0 - Changelog","doc":"This release updates to Buildroot 2021.05 and OTP 24.0.2. If you have made a\ncustom system off this one, please review the `nerves_system_br v1.16.0` release\nnotes.\n\n* Updated dependencies\n  * [nerves_system_br v1.16.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.16.0)\n  * [Buildroot 2021.05](http://lists.busybox.net/pipermail/buildroot/2021-June/311946.html)\n  * [Erlang/OTP 24.0.2](https://erlang.org/download/OTP-24.0.2.README)\n\n* Improvements\n  * This release now contains debug symbols and includes the Build-ID in the\n    ELF headers. This makes it easier to get stack traces from C programs. As\n    before, the Nerves tooling strips all symbols from firmware images, so this\n    won't make programs bigger.\n  * Enable compile-time `wpa_supplicant` options to support WPA3, mesh\n    networking, WPS and autoscan.","ref":"changelog.html#v1-16-0"},{"type":"extras","title":"v1.15.1 - Changelog","doc":"This is a security/bug fix release that updates to Buildroot 2021.02.1 and OTP\n23.3.1. It should be safe for everyone to apply.\n\n* Improvements\n  * espeak has been removed from the default install to trim 13 MB off the root\n    filesystem\n\n* Updated dependencies\n  * [nerves_system_br v1.15.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.15.1)\n  * [Buildroot 2021.02](http://lists.busybox.net/pipermail/buildroot/2021-April/307970.html)\n  * [Erlang/OTP 23.3.1](https://erlang.org/download/OTP-23.3.1.README)","ref":"changelog.html#v1-15-1"},{"type":"extras","title":"v1.15.0 - Changelog","doc":"This release updates to Buildroot 2021.02 and OTP 23.2.7. If you have made a\ncustom system off this one, please review the `nerves_system_br v1.15.0` release\nnotes.\n\nThe Nerves toolchain has also been updated to v1.4.2. This brings in Linux 4.14\nheaders to enable use of cdev and eBPF. This won't affect most users.\n\n* Updated dependencies\n  * [nerves_system_br v1.15.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.15.0)\n  * [Buildroot 2021.02](http://lists.busybox.net/pipermail/buildroot/2021-March/305168.html)\n  * [Erlang/OTP 23.2.7](https://erlang.org/download/OTP-23.2.7.README)\n  * [nerves toolchains v1.4.2](https://github.com/nerves-project/toolchains/releases/tag/v1.4.2)","ref":"changelog.html#v1-15-0"},{"type":"extras","title":"v1.14.0 - Changelog","doc":"This release updates to Buildroot 2020.11.2, GCC 10.2 and OTP 23.2.4.\n\nWhen migrating custom systems based, please be aware of the following important\nchanges:\n\n* There's a new `getrandom` syscall that is made early in BEAM startup. This has\n  the potential to block the BEAM before Nerves can start `rngd` to provide\n  entropy. We have not seen this issue here, but have updated `erlinit.config`\n  for the time being as a precaution.\n* The GCC 10.2.0 toolchain has a different name that calls out \"nerves\" as the\n  vendor and the naming is now more consistent with other toolchain providers.\n* Experimental support for tooling that requires more information about the\n  target has been added. The initial support focuses on zigler.\n\n* Updated dependencies\n  * [nerves_system_br: bump to v1.14.4](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.14.4)\n  * [Buildroot 2020.11.2](http://lists.busybox.net/pipermail/buildroot/2021-January/302574.html)\n  * [Erlang/OTP 23.2.4](https://erlang.org/download/OTP-23.2.4.README)\n  * [Nerves toolchains 1.4.1](https://github.com/nerves-project/toolchains/releases/tag/v1.4.1)","ref":"changelog.html#v1-14-0"},{"type":"extras","title":"v1.13.3 - Changelog","doc":"This is a bug fix release and contains no major changes.\n\n* Updated dependencies\n  * [nerves_system_br: bump to v1.13.7](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.13.7)\n  * [Erlang/OTP 23.1.5](https://erlang.org/download/OTP-23.1.5.README)","ref":"changelog.html#v1-13-3"},{"type":"extras","title":"v1.13.2 - Changelog","doc":"This release includes a patch release update to\n[Buildroot 2020.08.2](http://lists.busybox.net/pipermail/buildroot/2020-November/296830.html).\n\n* Updated dependencies\n  * [nerves_system_br: bump to v1.13.5](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.13.5)\n  * [erlinit 1.9.0](https://github.com/nerves-project/erlinit/releases/tag/v1.9.0)","ref":"changelog.html#v1-13-2"},{"type":"extras","title":"v1.13.1 - Changelog","doc":"The main change in this release is to bump the Linux kernel to 5.4. This follows\nthe kernel update in the Raspberry Pi OS.\n\nIf you have based a custom system off of this one, please inspect the\n`nerves_defconfig` for WiFi firmware changes. WiFi firmware is no longer being\npulled from the `rpi-wifi-firmware` since that package is out of date.\n\n* Updated dependencies\n  * [nerves_system_br: bump to v1.13.4](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.13.4)\n  * [Erlang/OTP 23.1.4](https://erlang.org/download/OTP-23.1.4.README)\n  * [boardid 1.10.0](https://github.com/nerves-project/boardid/releases/tag/v1.10.0)\n\n* Improvements\n  * Enabled reproducible builds in Buildroot to remove some timestamp and build\n    path differences in firmware images. This helps delta firmware updates.\n  * The memory cgroup controller is no longer enabled by default. This was an\n    upstream change. As a result, the memory cgroup directory is no longer\n    mounted.","ref":"changelog.html#v1-13-1"},{"type":"extras","title":"v1.13.0 - Changelog","doc":"This release updates to [Buildroot\n2020.08](http://lists.busybox.net/pipermail/buildroot/2020-September/290797.html) and OTP 23.1.1.\n\n* Updated dependencies\n  * [nerves_system_br: bump to v1.13.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.13.2)\n  * [Erlang/OTP 23.1.1](https://erlang.org/download/OTP-23.1.1.README)\n  * [erlinit 1.8.0](https://github.com/nerves-project/erlinit/releases/tag/v1.8.0)\n  * [nerves 1.7.0](https://github.com/nerves-project/nerves/releases/tag/v1.7.0)\n\n* New features\n  * Added support for updating the root filesystem using firmware patches.\n    See the [firmware patch docs](https://hexdocs.pm/nerves/experimental-features.html#content) for more information.","ref":"changelog.html#v1-13-0"},{"type":"extras","title":"v1.12.2 - Changelog","doc":"This release updates to [Buildroot\n2020.05.1](http://lists.busybox.net/pipermail/buildroot/2020-July/287824.html)\nand OTP 23.0.3 which are both bug fix releases.\n\n* Updated dependencies\n  * [nerves_system_br: bump to v1.12.4](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.12.4)\n  * [Erlang/OTP 23.0.3](https://erlang.org/download/OTP-23.0.3.README)\n  * [nerves_heart v0.3.0](https://github.com/nerves-project/nerves_heart/releases/tag/v0.3.0)\n\n* New features\n  * The `/data` directory now exists for storing application-specific data. It\n    is currently a symlink to `/root`. Using `/data` will eventually be\n    encouraged over `/root` even though currently there is no advantage. This\n    change makes it possible to start migrating paths in applications and\n    libraries.\n\n* Fixes\n  * Fixed old references to the `-Os` compiler flag. All C/C++ code will default\n    to using `-O2` now.","ref":"changelog.html#v1-12-2"},{"type":"extras","title":"v1.12.1 - Changelog","doc":"* Fixes\n  * Remove `nerves_system_linter` from hex package. This fixes mix dependency\n    errors in projects that reference systems with different\n    `nerves_system_linter` dependency specs.","ref":"changelog.html#v1-12-1"},{"type":"extras","title":"v1.12.0 - Changelog","doc":"This release updates the system to use Buildroot 2020.05 and Erlang/OTP 23.\nPlease see the respective release notes for updates and deprecations in both\nprojects for changes that may affect your application.\n\n* New features\n  * Support the Raspberry Pi Sense HAT's joystick\n  * Enable WiFi mesh support in the 802.11 stack\n\n* Updated dependencies\n  * [nerves_system_br v1.12.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.12.0)\n  * [Erlang/OTP 23.0.2](https://erlang.org/download/OTP-23.0.2.README)\n  * [Linux 4.19.118 (Raspberry Pi 1.2020601 tag)](https://github.com/raspberrypi/linux/tree/raspberrypi-kernel_1.20200601-1)\n  * [Raspberry Pi firmware 1.2020601](https://github.com/raspberrypi/firmware/tree/1.20200601)","ref":"changelog.html#v1-12-0"},{"type":"extras","title":"v1.11.2 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.11.4](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.11.4)\n  * Erlang 22.3.4.1\n  * fwup 1.7.0","ref":"changelog.html#v1-11-2"},{"type":"extras","title":"v1.11.1 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.11.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.11.2)\n  * Erlang 22.3.1\n  * erlinit 1.7.0 - tty initialization support\n  * fwup 1.6.0 - xdelta3/VCDIFF patch support\n  * Enable unixodbc so that Erlang's odbc application can be used in projects","ref":"changelog.html#v1-11-1"},{"type":"extras","title":"v1.11.0 - Changelog","doc":"This release updates Buildroot to 2020.02 and upgrades gcc from 8.3 to 9.2.\nWhile this is a minor version bump due to the Buildroot release update, barring\nadvanced usage of Nerves, this is a straightforward update from v1.10.2.\n\n* Updated dependencies\n  * [nerves_system_br v1.11.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.11.0)\n  * linux 4.19.97 (raspberrypi-kernel_1.20200212-1 tag)\n  * Erlang 22.2.8","ref":"changelog.html#v1-11-0"},{"type":"extras","title":"v1.10.2 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.10.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.10.2)\n  * Erlang 22.2.4","ref":"changelog.html#v1-10-2"},{"type":"extras","title":"v1.10.1 - Changelog","doc":"* Enhancements\n  * Set `expand=true` on the application data partition. This will only take\n    effect for users running the complete task, fwup will not expand application\n    data partitions that exist during upgrade tasks.\n\n* Updated dependencies\n  * [nerves_system_br v1.10.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.10.1)\n  * Erlang 22.2.3","ref":"changelog.html#v1-10-1"},{"type":"extras","title":"v1.10.0 - Changelog","doc":"This release updates Buildroot to 2019.11 with security and bug fix updates\nacross Linux packages. Enables dnsd, udhcpd and ifconfig in the default\nBusybox configuration to support `vintage_net` and `vintage_net_wizard`.\nSee the `nerves_system_br` notes for details.\n\n* Updated dependencies\n  * [nerves_system_br v1.10.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.10.0)\n  * Erlang 22.1.8","ref":"changelog.html#v1-10-0"},{"type":"extras","title":"v1.9.2 - Changelog","doc":"This release updates Buildroot to 2019.08.2 with security and bug fix updates\nacross Linux packages. See the `nerves_system_br` notes for details.\nErlang/OTP is now at 22.1.7.\n\n* Updated dependencies\n  * [nerves_system_br v1.9.5](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.9.5)","ref":"changelog.html#v1-9-2"},{"type":"extras","title":"v1.9.1 - Changelog","doc":"This release pulls in security and bug fix updates from `nerves_system_br`.\nErlang/OTP is now at 22.1.1.\n\n* Updated dependencies\n  * [nerves_system_br v1.9.4](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.9.4)\n  * linux - update to the raspberrypi-kernel_1.20190925-1 tag\n\n* Enhancements\n  * The Raspberry Pi Touchscreen drivers are included by default now so that its\n    possible to use Scenic without any changes to the system.","ref":"changelog.html#v1-9-1"},{"type":"extras","title":"v1.9.0 - Changelog","doc":"This release updates Buildroot to 2019.08 with security and bug fix updates\nacross Linux packages. See the `nerves_system_br` notes for details.\n\n* Updated dependencies\n  * [nerves_system_br v1.9.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.9.2)\n\n* Enhancements\n  * Support a variety of USB->UART adapters so more devices work out-of-the-box","ref":"changelog.html#v1-9-0"},{"type":"extras","title":"v1.8.2 - Changelog","doc":"This release fixes an issue that broke display output on small LCD screens.\nUpdating the Raspberry Pi firmware to the latest from the Raspberry Pi\nFoundation fixed the issue. See\nhttps://github.com/fhunleth/rpi_fb_capture/issues/2 for details.\n\n* Updated dependencies\n  * [nerves_system_br v1.8.5](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.8.5)","ref":"changelog.html#v1-8-2"},{"type":"extras","title":"v1.8.1 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.8.4](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.8.4)\n  * Linux 4.19.58 with patches from the Raspberry Pi Foundation","ref":"changelog.html#v1-8-1"},{"type":"extras","title":"v1.8.0 - Changelog","doc":"This release\n\nThis release updates Erlang to OTP 22 and gcc from version 7.3.0 to 8.3.0.\nSee the nerves_system_br and toolchain release notes for more information.\n\n* Enhancements\n  * Enable source-based routing in the Linux kernel to support [vintage_net](https://github.com/nerves-networking/vintage_net)\n\n* Updated dependencies\n  * Erlang 22.0.4\n  * [nerves_system_br v1.8.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.8.2)\n  * [nerves_toolchain_arm_unknown_linux_gnueabihf v1.2.0](https://github.com/nerves-project/toolchains/releases/tag/v1.2.0)","ref":"changelog.html#v1-8-0"},{"type":"extras","title":"v1.7.2 - Changelog","doc":"* Bux fixes\n  * Add TAR option `--no-same-owner` to fix errors when untarring artifacts as\n    the root user.\n* Updated dependencies\n  * [nerves_system_br v1.7.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.7.2)","ref":"changelog.html#v1-7-2"},{"type":"extras","title":"v1.7.1 - Changelog","doc":"* Improvements\n  * Bump C compiler options to `-O2` from `-Os`. This provides a small, but\n    measurable performance improvement (500ms at boot in a trivial project\n    tested on [nerves_system_rpi0](https://github.com/nerves-project/nerves_system_rpi0)).\n\n* Updated dependencies\n  * [nerves_system_br v1.7.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.7.1)","ref":"changelog.html#v1-7-1"},{"type":"extras","title":"v1.7.0 - Changelog","doc":"This release bumps the Linux kernel to 4.19.25. This change had an impact on how\nthe WiFi regulatory database gets loaded into the kernel. Instead of building it\ninto the kernel as previously done, the kernel loads it on demand. This requires\nthat all WiFi drivers be built as kernel modules so that the database isn't\nloaded before the root filesystem is mounted. If you made a custom system and\nsee boot errors about not being able to load the regulatory database, this is\nthe problem.\n\n* Updated dependencies\n  * [nerves_system_br v1.7.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.7.0)\n  * Linux 4.19.25 with patches from the Raspberry Pi Foundation","ref":"changelog.html#v1-7-0"},{"type":"extras","title":"v1.6.3 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.6.8](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.6.8)\n  * Erlang 21.2.6","ref":"changelog.html#v1-6-3"},{"type":"extras","title":"v1.6.2 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.6.6](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.6.6)\n  * Erlang 21.2.4\n  * boardid 1.5.3","ref":"changelog.html#v1-6-2"},{"type":"extras","title":"v1.6.1 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.6.5](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.6.5)\n  * Erlang 21.2.2\n  * boardid 1.5.2\n  * erlinit 1.4.9\n  * OpenSSL 1.1.1a\n  * Linux 4.14.89 with patches from the Raspberry Pi Foundation\n\n* Enhancements\n  * Moved boardid config from inside erlinit.config to /etc/boardid.config\n  * Compile gpiomem into the Linux kernel\n  * Enable pstore, an in-memory buffer that can capture logs, kernel\n    oops and other information when unexpected reboots. The buffer can be\n    recovered on the next boot where it can be inspected.","ref":"changelog.html#v1-6-1"},{"type":"extras","title":"v1.6.0 - Changelog","doc":"This pulls in a pending patch in Buildroot to update the version of\nOpenSSL from 1.0.2 to 1.1.0h. This fixes what appears to be issues with\nErlang using OpenSSL engines. It also enables Erlang crypto algorithms\nsuch as ed25519 that have been added in recent Erlang releases.\n\n* Updated dependencies\n  * [nerves_system_br v1.6.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.6.1)\n  * Erlang 21.2\n* Added dependencies\n  * wpa_passphrase\n  * libp11 0.4.9","ref":"changelog.html#v1-6-0"},{"type":"extras","title":"v1.5.1 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.5.3](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.5.3)","ref":"changelog.html#v1-5-1"},{"type":"extras","title":"v1.5.0 - Changelog","doc":"This release updates the Linux kernel from 4.4 to 4.14.71.\n\n* Enhancements\n  * Added Alsa utils `aplay` and `amixer` for audio support.\n  * Added `espeak` a speech synthesizer for text to audio.\n  * Automatically reboot if the Linux kernel panics (defaults to a 10 second\n    delay before the reboot)\n\n* Updated dependencies\n  * [nerves_system_br v1.5.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.5.2)\n  * Linux 4.14.71 with patches from the Raspberry Pi Foundation\n  * Erlang 21.0.9","ref":"changelog.html#v1-5-0"},{"type":"extras","title":"v1.4.0 - Changelog","doc":"This release contains various updates to provisioning variables and data.\n\n**Host requirements**\n\nBuilding firmware using this system requires `fwup` to be updated on your\nhost computer to at least `v1.2.5`. The target minimum version requirement\nhas not changed from `0.15.0`.\n\n**Serial numbers**\n\nDevice serial numbers are now set using `NERVES_SERIAL_NUMBER` instead of\n`SERIAL_NUMBER`. This is to reduce ambiguity on the source of the serial\nby name spacing it along side other Nerves variables. The U-Boot environment\nkey has also changed from `serial_number` to `nerves_serial_number`. The\nerlinit.config has been updated to provide backwards compatibility for setting\nthe hostname from the serial number by checking for `nerves_serial_number`\nand falling back to `serial_number`.\n\n**Custom provisioning**\n\nProvisioning data is applied at the time of calling the `fwup` task `complete`.\nThe `complete` task is executed when writing the firmware to the target disk.\nDuring this time, `fwup` will include the contents of a provisioning file\nlocated at `${NERVES_SYSTEM}/images/fwup_include/provisioning.conf`. By default,\nthis file only sets `nerves_serial_number`. You can add additional provisioning\ndata by overriding the location of this file to include your own by setting\nthe environment variable `NERVES_PROVISIONING`. If you override this variable\nyou will be responsible for also setting `nerves_serial_number`.\n\n* Updated dependencies\n  * [nerves_system_br v1.4.5](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.4.5)","ref":"changelog.html#v1-4-0"},{"type":"extras","title":"v1.3.0 - Changelog","doc":"This release upgrades gcc from version 6.3.0 to 7.3.0. See the toolchain release\nnotes for more information.\n\n* Updated dependencies\n  * [nerves_system_br v1.4.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.4.1)\n  * [nerves_toolchain_arm_unknown_linux_gnueabihf v1.1.0](https://github.com/nerves-project/toolchains/releases/tag/v1.1.0)","ref":"changelog.html#v1-3-0"},{"type":"extras","title":"v1.2.1 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.3.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.3.2)\n* Enhancements\n  * Enable RTL8188EU driver","ref":"changelog.html#v1-2-1"},{"type":"extras","title":"v1.2.0 - Changelog","doc":"This release updates Erlang to OTP 21.0\n\n* Updated dependencies\n  * [nerves_system_br v1.3.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.3.0)","ref":"changelog.html#v1-2-0"},{"type":"extras","title":"v1.1.1 - Changelog","doc":"This release fixes some issues and adds firmware UUID support. This support can\nbe used to unambiguously know what's running on a device.\n\n* Updated dependencies\n  * [nerves_system_br v1.2.2](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.2.2)\n\n* Bug fixes\n  * Empty serial numbers stored in the U-Boot environment would be used instead\n    of reverting to devices IDs built into the CPU or board.\n  * It wasn't possible to enable QtWebEngine (needed for kiosk apps)","ref":"changelog.html#v1-1-1"},{"type":"extras","title":"v1.1.0 - Changelog","doc":"This release adds official support for provisioning serial numbers to devices.\nOther information can be provisioned in a similar manner. See the README.md for\ndetails.\n\nBuildroot was also updated to 2018.05. Be sure to review the `nerves_system_br`\nlink for the changes in the embedded Linux components.\n\n* Updated dependencies\n  * [nerves_system_br v1.2.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.2.0)\n\n* New features\n  * More `wpa-supplicant` features were enabled to support more WiFi use-cases","ref":"changelog.html#v1-1-0"},{"type":"extras","title":"v1.0.0 - Changelog","doc":"This release contains updates to Erlang and heart from `nerves_system_br` and\nmostly cosmetic changes to synchronize it to the other Raspberry Pi systems. The\ntrivial `.fw` files are no longer created by CI scripts. If you've forked this\nproject and are building systems using CI, make sure to update your publish\nscripts.\n\n* Updated dependencies\n  * [nerves_system_br v1.0.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.0.0)\n  * [nerves_toolchain v1.0.0](https://github.com/nerves-project/toolchains/releases/tag/v1.0.0)\n  * [nerves v1.0.0](https://github.com/nerves-project/nerves/releases/tag/1.0.0)","ref":"changelog.html#v1-0-0"},{"type":"extras","title":"v1.0.0-rc.0 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v1.0.0-rc.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v1.0.0-rc.0)\n  * [nerves_toolchain v1.0.0-rc.0](https://github.com/nerves-project/toolchains/releases/tag/v1.0.0-rc.0)\n  * [nerves v1.0.0-rc.0](https://github.com/nerves-project/nerves/releases/tag/1.0.0-rc.0)","ref":"changelog.html#v1-0-0-rc-0"},{"type":"extras","title":"v0.20.0 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v0.17.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v0.17.0)\n  * [nerves_toolchain v0.13.0](https://github.com/nerves-project/toolchains/releases/tag/v0.13.0)\n  * [nerves v0.9.0](https://github.com/nerves-project/nerves/releases/tag/v0.9.0)","ref":"changelog.html#v0-20-0"},{"type":"extras","title":"v0.19.1 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v0.16.3](https://github.com/nerves-project/nerves_system_br/releases/tag/v0.16.3)\n    This fixes the call to otp_build so that it always uses Buildroot's version\n    the autoconf tools.","ref":"changelog.html#v0-19-1"},{"type":"extras","title":"v0.19.0 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v0.16.1-2017-11](https://github.com/nerves-project/nerves_system_br/releases/tag/v0.16.1-2017-11)\n\n* Enhancements\n  * Reboot automatically if Erlang VM exits - This is consistent with other\n    Nerves systems. See rootfs_overlay/etc/erlinit.config if undesired.\n  * Start running nerves_system_linter to check for configuration errors.\n  * Disable console blanking for HDMI to make it easier to capture error messages.\n  * Automount the boot partition readonly at `/boot`\n  * Support for reverting firmware.\n\n    See [Reverting Firmware](https://hexdocs.pm/nerves_runtime/readme.html#reverting-firmware) for more info on reverting firmware.\n\n    See [fwup-revert.conf](https://github.com/nerves-project/nerves_system_rpi/blob/master/fwup-revert.conf) for more information on how fwup handles reverting.","ref":"changelog.html#v0-19-0"},{"type":"extras","title":"v0.18.0 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v0.15.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v0.15.0)\n  * [toolchain v0.12.1](https://github.com/nerves-project/toolchains/releases/tag/v0.12.1)\n\n* Enhancements\n  * Support for nerves 0.8. Moves nerves.exs into mix.exs","ref":"changelog.html#v0-18-0"},{"type":"extras","title":"v0.17.1 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v0.14.1](https://github.com/nerves-project/nerves_system_br/releases/tag/v0.14.1)","ref":"changelog.html#v0-17-1"},{"type":"extras","title":"v0.17.0 - Changelog","doc":"* Updated dependencies\n  * [nerves_system_br v0.14.0](https://github.com/nerves-project/nerves_system_br/releases/tag/v0.14.0)\n    * [Buildroot 2017.08](https://git.busybox.net/buildroot/plain/CHANGES?id=2017.08)\n    * [fwup 0.17.0](https://github.com/fhunleth/fwup/releases/tag/v0.17.0)\n    * [erlinit 1.2.0](https://github.com/nerves-project/erlinit/releases/tag/v1.2.0)\n    * [nbtty 0.3.0](https://github.com/fhunleth/nbtty/releases/tag/v0.3.0)\n\n* Enhancements\n  * Add global patch directory\n\n  This is required to pull in the e2fsprogs patch that's needed now that\n  util-linux's uuid_generate function calls getrandom and can block\n  indefinitely for the urandom pool to initialize","ref":"changelog.html#v0-17-0"},{"type":"extras","title":"v0.16.1 - Changelog","doc":"* Updated dependencies\n  * nerves_system_br v0.13.7","ref":"changelog.html#v0-16-1"},{"type":"extras","title":"v0.16.0 - Changelog","doc":"This release contains an updated toolchain with Linux 4.1 Headers.\nYou will have to clean and compile any c/c++ code in your project and\ndependencies. Failure to do so will result in an error when producing firmware.\n\n* nerves_system_br v0.13.5\n  * fwup 0.15.4\n\n* Nerves toolchain v0.11.0","ref":"changelog.html#v0-16-0"},{"type":"extras","title":"v0.15.0 - Changelog","doc":"* nerves_system_br v0.13.3\n  * erlinit 1.1.4\n\n* New features\n  * Firmware updates verify that they're updating the right target. If the target\n    doesn't say that it's an `rpi2` through the firmware metadata, the update\n    will fail.\n  * Added meta-misc and meta-vcs-identifier to the `fwup.conf` metadata for use\n    by users and for the regression test framework\n  * Use String.trim instead of String.strip to silence Elixir 1.5 warnings","ref":"changelog.html#v0-15-0"},{"type":"extras","title":"v0.14.0 - Changelog","doc":"* nerves_system_br v0.13.2\n  * OTP 20\n  * erlinit 1.1.3\n  * fwup 0.15.3","ref":"changelog.html#v0-14-0"},{"type":"extras","title":"v0.13.0 - Changelog","doc":"* nerves_system_br v0.12.1\n  * erlinit 1.1.1\n  * fwup 0.15.0\n\n* New features\n  * The application data partition is now `ext4`. This greatly improves its\n    robustness to corruption. Nerves.Runtime contains code to initialize it on\n    first boot.\n  * Firmware images now contain metadata that can be queried at runtime (see\n    Nerves.Runtime.KV\n  * Increased GPU memory to support Pi Camera V2","ref":"changelog.html#v0-13-0"},{"type":"extras","title":"v0.12.1 - Changelog","doc":"* New features\n  * 8192cu driver is enabled. This aligns this system with nerves_system_rpi\n    in terms of WiFi support.","ref":"changelog.html#v0-12-1"},{"type":"extras","title":"v0.12.0 - Changelog","doc":"* nerves_system_br v0.10.0\n  * Buildroot 2017.02\n  * Erlang/OTP 19.3\n\n* New features\n  * Upgraded the Linux kernel from 4.4.43 -> 4.4.50. Due to the coupling\n    between the Linux kernel and rpi-firmware and possibly rpi-userland, if\n    you have a custom system based off this, you should update your Linux\n    kernel as well. (see `nerves_defconfig`)","ref":"changelog.html#v0-12-0"},{"type":"extras","title":"v0.11.0 - Changelog","doc":"* New features\n  * Enabled USB_SERIAL and FTDI_SIO support. Needed for connecting with Arduino to the USB ports\n  * Support for Nerves 0.5.0","ref":"changelog.html#v0-11-0"},{"type":"extras","title":"v0.10.0 - Changelog","doc":"* New features\n  * Upgraded the Linux kernel to 4.4.43. This also removes the\n    call to mkknlimg which is no longer needed.\n  * Bump toolchain to use gcc 5.3 (previously using gcc 4.9.3)","ref":"changelog.html#v0-10-0"},{"type":"extras","title":"v0.9.0 - Changelog","doc":"This version switches to using the `nerves_package` compiler. This will\nconsolidate overall deps and compilers.\n\n* Nerves.System.BR v0.8.1\n  * Support for distillery\n  * Support for nerves_package compiler","ref":"changelog.html#v0-9-0"},{"type":"extras","title":"v0.7.0 - Changelog","doc":"When upgrading to this version, be sure to review the updates to\nnerves_defconfig if you have customized this system.\n\n* nerves_system_br v0.6.2\n  * Package updates\n    * Buildroot 2016.08\n    * Linux 4.4","ref":"changelog.html#v0-7-0"},{"type":"extras","title":"v0.6.1 - Changelog","doc":"* Package versions\n  * Nerves.System.BR v0.6.1\n\n* New features\n  * All Raspberry Pi 2-specific configuration is now in this repository","ref":"changelog.html#v0-6-1"},{"type":"extras","title":"v0.6.0 - Changelog","doc":"* Nerves.System.BR v0.6.0\n  * Package updates\n    * Erlang OTP 19\n    * Elixir 1.3.1\n    * fwup 0.8.0\n    * erlinit 0.7.3\n    * bborg-overlays (pull in I2C typo fix from upstream)\n  * Bug fixes\n    * Synchronize file system kernel configs across all platforms","ref":"changelog.html#v0-6-0"},{"type":"extras","title":"v0.5.2 - Changelog","doc":"* Enhancements\n  * Enabled USB Printer kernel mod. Needs to be loaded with `modprobe` to use\n* Bug Fixes(raspberry pi)\n  * Enabled multicast in linux config for rpi/rpi2/rpi3/ev3","ref":"changelog.html#v0-5-2"},{"type":"extras","title":"v0.5.1 - Changelog","doc":"* Nerves.System.BR v0.5.1\n  * Bug Fixes(nerves-env)\n    * Added include paths to CFLAGS and CXXFLAGS\n    * Pass sysroot to LDFLAGS","ref":"changelog.html#v0-5-1"},{"type":"extras","title":"v0.5.0 - Changelog","doc":"* Nerves.System.BR v0.5.0\n  * New features\n    * WiFi drivers enabled by default on RPi2 and RPi3\n    * Include wireless regulatory database in Linux kernel by default\n      on WiFi-enabled platforms. Since kernel/rootfs are read-only and\n      coupled together for firmware updates, the normal CRDA/udev approach\n      isn't necessary.\n    * Upgraded the default BeagleBone Black kernel from 3.8 to 4.4.9. The\n      standard BBB device tree overlays are included by default even though the\n      upstream kernel patches no longer include them.\n    * Change all fwup configurations from two step upgrades to one step\n      upgrades. If you used the base fwup.conf files to upgrade, you no\n      longer need to finalize the upgrade. If not, there's no change.","ref":"changelog.html#v0-5-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}